@@ -21,7 +21,7 @@ use overload(
 
 use namespace::autoclean;
 
-our $VERSION = '0.014_01';
+our $VERSION = '0.014_02';
 
 # only a few explicitly named attributes.
 # everything else is through AUTOLOAD.
@@ -572,7 +572,7 @@ sub stringify {
 
 sub _write_utf8 {
     my ( $self, $file, $buf ) = @_;
-    binmode $file, ':utf8';
+    binmode $file, ':encoding(UTF-8)';
     print {$file} $buf;
 }
 
