@@ -9,7 +9,7 @@ use SWISH::3 qw( :constants );
 
 use namespace::autoclean;
 
-our $VERSION = '0.014_01';
+our $VERSION = '0.014_02';
 
 has 'invindex' => ( is => 'rw', isa => DeziInvIndex, required => 1 );
 has 'file' => ( is => 'ro', isa => 'Path::Class::File', coerce => 1, );
@@ -156,7 +156,11 @@ at this time.
 All the L<SWISH::3> constants are imported into this namespace,
 including:
 
-=head2 SWISH_DOC_PROP_MAP
+=over 4
+
+=item * SWISH_DOC_PROP_MAP
+
+=back
 
 =head1 METHODS
 
@@ -167,7 +171,7 @@ Default is C<swish.xml>.
 
 =head2 swish_header_file
 
-Alias for header_file(). For backwards compatability with SWISH::Prog.
+Alias for header_file(). For backwards compatibility with SWISH::Prog.
 
 =head2 BUILD
 
